==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/sapdb/sapdb/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("MySQL's MaxDB driver")
url = "http://www.mysql.com/products/maxdb/sapdbapi.html"
doc = """
Description
-----------
Python driver for MaxDB/SAPDB version 7.x+.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* host       -- This is the MaxDB host for your connection (optional)
* dbname     -- This is the MaxDB database to use (required)
* timeout    -- Command timeout in seconds (optional)
* isolation  -- Isolation level (optional) (0, 1 [default], 10, 15, 2, 20, 3, 30)
* sqlmode    -- INTERNAL (default) or ORACLE (optional)
* sqlsubmode -- ODBC or empty (optional)

Examples
--------
# This connection uses the SAP DB  driver
# We will be connecting to the SAP DB server on
# "localhost" to a database called "TST".
[sapdb]
comment = XYZ Development Database
provider = sapdb
host=dbs.mydomain.com
dbname = TST
timeout = 900

Notes
-----
1. This driver has been partially tested.  If you are successfully using
   this driver, please let us know.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/sapdb/sapdb/Info.py <==
# GNU Enterprise Common - Database Drivers - MaxDB/SAP-DB
#
# Copyright 2001-2005 Free Software Foundation
#
# This file is part of GNU Enterprise
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: Info.py 6851 2005-01-03 20:59:28Z jcater $
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("MySQL's MaxDB driver")
url = "http://www.mysql.com/products/maxdb/sapdbapi.html"
doc = """
Description
-----------
Python driver for MaxDB/SAPDB version 7.x+.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* host       -- This is the MaxDB host for your connection (optional)
* dbname     -- This is the MaxDB database to use (required)
* timeout    -- Command timeout in seconds (optional)
* isolation  -- Isolation level (optional) (0, 1 [default], 10, 15, 2, 20, 3, 30)
* sqlmode    -- INTERNAL (default) or ORACLE (optional)
* sqlsubmode -- ODBC or empty (optional)

Examples
--------
# This connection uses the SAP DB  driver
# We will be connecting to the SAP DB server on
# "localhost" to a database called "TST".
[sapdb]
comment = XYZ Development Database
provider = sapdb
host=dbs.mydomain.com
dbname = TST
timeout = 900


Notes
-----

1.  The driver is fully functional
"""
